'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _typeof = typeof Symbol === "function" && typeof Symbol.iterator === "symbol" ? function (obj) { return typeof obj; } : function (obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol ? "symbol" : typeof obj; };

exports.default = function (babel) {
  if (schemaData) {
    return (0, _babelRelayPlugin2.default)(schemaData)(babel);
  } else {
    return {
      visitor: {}
    };
  }
};

var _path = require('path');

var _babelRelayPlugin = require('babel-relay-plugin');

var _babelRelayPlugin2 = _interopRequireDefault(_babelRelayPlugin);

var _graphql = require('graphql');

var _utilities = require('graphql/utilities');

var _deasync = require('deasync');

var _syncRequest = require('sync-request');

var _syncRequest2 = _interopRequireDefault(_syncRequest);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var packageJson = require(process.cwd() + '/package.json');
var config = packageJson['react-relay-schema'];

if (!config) {
  throw new Error('\nNo relay schema configuration found in package.json.\nPlease provide a schema endpoint for the key "react-relay-schema"');
}

var source = void 0;
if ((typeof config === 'undefined' ? 'undefined' : _typeof(config)) === 'object') {
  source = process.env[config.env];
} else {
  source = config;
}

var sourceType = void 0;
if (source.startsWith('http')) {
  sourceType = 'url';
} else if (source.endsWith('json')) {
  sourceType = 'json';
} else if (source.endsWith('js')) {
  sourceType = 'schema';
} else {
  throw new Error('Invalid relay schema source');
}

var schemaData = void 0;

(function () {
  switch (sourceType) {

    case 'schema':
      var schemaSource = require((0, _path.resolve)(source));
      var wait = true;

      (0, _graphql.graphql)(schemaSource, _utilities.introspectionQuery).then(function (result) {
        schemaData = result.data;
        wait = false;
      });

      // TODO find a cleaner way to do this
      (0, _deasync.loopWhile)(function () {
        return wait;
      });

      break;

    case 'json':
      var schema = require((0, _path.resolve)(source));
      schemaData = schema.data;

      break;

    case 'url':
      var res = (0, _syncRequest2.default)('GET', source);
      if (res.statusCode !== 200) {
        throw new Error('Couldn\'t fetch schema from ' + source);
      }

      var result = JSON.parse(res.getBody());
      schemaData = result.data;

      break;

    default:
      throw new Error('Invalid method. Valid keys are `schema, json, url`');
  }
})();

console.log('\nRelay schema successfully loaded from ' + source);
